tdlib: Algorithms for computing tree decompositions of graphs
=============================================================

Description
-----------

This library, now known as treedec,
provides algorithms concerning tree decompositions.


License
-------

- GNU General Public License v2
- GNU General Public License v3


Upstream Contact
----------------

- https://gitlab.com/freetdi/treedec
- https://github.com/freetdi/tdlib
- https://github.com/felix-salfelder
